#
# spec file for package perl-System-Command
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name System-Command
Name:           perl-System-Command
Version:        1.122
Release:        1.9
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Object for running system commands
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BO/BOOK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IPC::Run)
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(IPC::Run)
%{perl_requires}

%description
System::Command is a class that launches external system commands and
return an object representing them, allowing to interact with them through
their 'STDIN', 'STDOUT' and 'STDERR' handles.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sun Feb  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.122
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.122 2023-02-04 BOOK
    [TESTS]
  - Use $^X in Perl tests, instead of 'perl' (RT #141674 by SREZIC)
  - Fix t/30-exit.t to pass on Windows (RT #133230 by Lisa Hansen)
  - Drop some author developement modules from BuildRequires (GH #30 by OALDERS)
* Thu Jun  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.121
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.121 2020-06-03 BOOK
  - No functional change: update Changes and contributors
  1.120 2020-06-03 BOOK
    [ENHANCEMENTS]
  - System::Command does not clobber $? and $! any more
    when DESTOYed (GH #27 by MMCCLIMON)
* Mon Apr  2 2018 coolo@suse.com
- updated to 1.119
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.119 Mon Apr 2 2018
    [TESTS]
  - Various test fixes for Win32 and "perl in space" (ETJ)
    [DOCUMENTATION]
  - document the 'input_record_separator' option to loop_on()
* Sun Jun 12 2016 coolo@suse.com
- updated to 1.118
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.118 Thu Jun 2 2016
    [ENHANCEMENTS]
  - Avoid calling waitpid() more than necessary in _reap()
  - Close all pipes when loop_on() ends successfully, and avoid a warning
    when the exit value is not available
    [TESTS]
  - Fix t/20-zombie.t, which was broken in Strawberry Perl (viviparous)
* Tue Jan 19 2016 coolo@suse.com
- updated to 1.117
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.117 Sun Jan 17 2016
    [ENHANCEMENT]
  - new method loop_on() to run callbacks on the command output/errput
* Wed Jan  6 2016 coolo@suse.com
- updated to 1.116
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.116 Sun Jan 3 2016
    [BUG FIX]
  - Fix for the 'interactive' option (RKINYON)
    [COMPATIBILITY]
  - Remove a warning that was showing up under Perl 5.6
* Mon Sep 28 2015 coolo@suse.com
- updated to 1.115
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.115 Mon Sep 28 2015
    [BUG FIX]
  - ensure test counts and skip counts remain tied together (MITHALDU)
    [DOCUMENTATION]
  - for each option/feature, document in which version it appeared
* Sun Sep 20 2015 coolo@suse.com
- updated to 1.114
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.114 Fri Sep 18 2015
    [ENHANCEMENTS]
  - added proper accessors for the following System::Command::Reaper
    attributes: sdtin, stdout, stderr, exit, signal, core
    (after discussion with TIMB in RT #106330)
  - added 'exit', 'signal', 'core' options to System::Command, to allow
    direct update of variables at reaping time
  - added the 'interactive' option, to make it possible to run interactive
    commands directly with system (after discussion with TIMB in RT #106330)
* Sun Sep  6 2015 coolo@suse.com
- updated to 1.113
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.113 Sun Sep 6 2015
    [ENHANCEMENTS]
  - add proper accessors for the following System::Command::Reaper
    attributes: sdtin, stdout, stderr, exit, signal, core
    (after discussion with TIMB in RT #106330)
  - System::Command::close() now returns the object itself (RT #106867)
    [DOCUMENTATION]
  - document the return value of close() can be used to access the
    value of exit, signal and core
* Sat Aug  1 2015 coolo@suse.com
- updated to 1.112
  see /usr/share/doc/packages/perl-System-Command/Changes
  1.112 Sat Jul 25 2015
    [ENHANCEMENTS]
  - the 'trace' option now also outputs some information about process
    termination and status (as requested by TIMB in RT #106046)
* Fri Apr 17 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
